# Rhasspy Supervisor

[![Continous Integration](https://github.com/rhasspy/rhasspy-supervisor/workflows/Tests/badge.svg)](https://github.com/rhasspy/rhasspy-supervisor/actions)
[![PyPI package version](https://img.shields.io/pypi/v/rhasspy-supervisor.svg)](https://pypi.org/project/rhasspy-supervisor)
[![Python versions](https://img.shields.io/pypi/pyversions/rhasspy-supervisor.svg)](https://www.python.org)
[![GitHub license](https://img.shields.io/github/license/rhasspy/rhasspy-supervisor.svg)](https://github.com/rhasspy/rhasspy-supervisor/blob/master/LICENSE)

Generates a supervisord configuration from a Rhasspy profile.
